@@ -4,6 +4,7 @@ import plotly.express as px
 import plotly.graph_objs as go
 import pprint
 import scipy.stats as sts
+import time
 
 import dtale.global_state as global_state
 
@@ -140,6 +141,7 @@ class ColumnAnalysis(object):
             cols=global_state.get_dtypes(self.data_id),
             dtype=self.dtype,
             chart_type=self.analysis_type,
+            timestamp=round(time.time() * 1000),
             **return_data
         )
 
@@ -154,15 +156,20 @@ class HistogramAnalysis(object):
         hist_kwargs = {"density": True} if self.density else {"bins": self.bins}
         hist_data, hist_labels = np.histogram(series, **hist_kwargs)
         hist_data = [json_float(h) for h in hist_data]
-        return (
-            dict(
-                labels=[
-                    "{0:.1f}".format(lbl) for lbl in hist_labels[1:]
-                ],  # drop the first bin because of just a minimum
-                data=hist_data,
-            ),
-            hist_labels,
-        )
+        decimals = 1
+        # drop the first bin because of just a minimum
+        labels = [
+            "".join(["{0:.", "{}".format(decimals), "f}"]).format(lbl)
+            for lbl in hist_labels[1:]
+        ]
+        while len(set(labels)) < len(labels) or decimals > 10:
+            decimals += 1
+            labels = [
+                "".join(["{0:.", "{}".format(decimals), "f}"]).format(lbl)
+                for lbl in hist_labels[1:]
+            ]
+
+        return dict(labels=labels, data=hist_data), hist_labels
 
     def build(self, parent):
         if parent.classifier == "D":
